@@ -1,10 +1,11 @@
 use std::collections::HashMap;
 use std::{error, fmt};
 
-use crate::DomainEvent;
 use serde::de::DeserializeOwned;
 use serde::{Deserialize, Serialize};
 
+use crate::DomainEvent;
+
 /// In CQRS (and Domain Driven Design) an `Aggregate` is the fundamental component that
 /// encapsulates the state and application logic (aka business rules) for the application.
 /// An `Aggregate` is always an entity along with all objects associated with it.
@@ -83,6 +84,9 @@ pub trait Aggregate: Default + Serialize + DeserializeOwned + Sync + Send {
 pub enum AggregateError {
     /// The user has made an error, a String value contains a message to be delivered to the user.
     UserError(UserErrorPayload),
+    /// A command has been rejected due to a conflict with another command on the same aggregate
+    /// instance. This is usually handled by optimistic locking in systems backed by an RDBMS.
+    AggregateConflict,
     /// A technical error was encountered that prevented the command from being applied to the
     /// aggregate. In general the accompanying message should be logged for investigation rather
     /// than returned to the user.
@@ -107,12 +111,9 @@ impl error::Error for AggregateError {}
 impl fmt::Display for AggregateError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            AggregateError::TechnicalError(message) => {
-                write!(f, "{}", message)
-            }
-            AggregateError::UserError(message) => {
-                write!(f, "{}", message)
-            }
+            AggregateError::TechnicalError(message) => write!(f, "{}", message),
+            AggregateError::UserError(message) => write!(f, "{}", message),
+            AggregateError::AggregateConflict => write!(f, "aggregate conflict"),
         }
     }
 }
